@@ -23,7 +23,7 @@ class MessageService(PopbillBase):
         """생성자
             args
                 LinkID : 링크허브에서 발급받은 링크아이디(LinkID)
-                SecretKeye 링크허브에서 발급받은 비밀키(SecretKey)
+                SecretKey : 링크허브에서 발급받은 비밀키(SecretKey)
         """
         super(self.__class__, self).__init__(LinkID, SecretKey)
         self._addScope("150")
@@ -443,7 +443,7 @@ class MessageService(PopbillBase):
         """
         if ReceiptNum == None or len(ReceiptNum) != 18:
             raise PopbillException(-99999999, "접수번호가 올바르지 않습니다.")
-            
+
         if ReceiveNum == None or ReceiveNum == '':
             raise PopbillException(-99999999, "수신번호가 올바르지 않습니다.")
 
@@ -466,7 +466,7 @@ class MessageService(PopbillBase):
         """
         if RequestNum == None or RequestNum == '':
             raise PopbillException(-99999999, "요청번호가 입력되지 않았습니다.")
-            
+
         if ReceiveNum == None or ReceiveNum == '':
             raise PopbillException(-99999999, "수신번호가 올바르지 않습니다.")
 
@@ -603,8 +603,28 @@ class MessageService(PopbillBase):
 
         return self._httppost('/Message/States', postData, Corpnum, UserID)
 
+    def checkAutoDenyNumber(self, CorpNum, UserID=None):
+        """문자 발송이 차단된 사용자의 번호와 등록일 조회
+
+        Args:
+            CorpNum (str): 팝빌회원 사업자 번호
+            UserID (str, optional): 팝빌회원 아이디. Defaults to None.
+
+        Returns:
+            AutoDenyNumberInfo: 차단된 번호와, 차단 등록일
+        """
+        response = self._httpget(
+            "/Message/AutoDenyNumberInfo", CorpNum, UserID)
+
+        return AutoDenyNumberInfo(**response.__dict__)
 
 class MessageReceiver(object):
     def __init__(self, **kwargs):
         self.__dict__ = dict.fromkeys(['snd', 'rcv', 'rcvnm', 'msg', 'sjt', 'interOPRefKey'])
         self.__dict__.update(kwargs)
+
+
+class AutoDenyNumberInfo(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = dict.fromkeys(['smsdenyNumber', 'regDT'])
+        self.__dict__.update(kwargs)
